@@ -375,19 +375,17 @@ def install_app(project_name, settings_path=None, **settings_patches):
         if not config.has_option('uwsgi', key):
             config.set('uwsgi', key, value)
     # Options that must be overriden by beanstalk
-    with hide('everything'):
-        uid = local('id -u apache', capture=True)
     must_override_options = [
         ('socket', '127.0.0.1:%d' % uwsgi_port),
         ('chdir', project_source_path(project_name)),
         ('home', project_venv_path(project_name)),
-        ('uid', uid),
         ('logto', os.path.join(project_logs_path(project_name), 'uwsgi.log')),
     ]
     for key, value in must_override_options:
         config.set('uwsgi', key, value)
     # Remove options
     must_remove_options = [
+        'uid',
         'http',
         'https',
         'http-proxy',
